/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.fileresolver.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.tinygroup.appconfig.AppConfig;
import org.tinygroup.fileresolver.FileResolver;
import org.tinygroup.fileresolver.FullContextFileRepository;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.parser.filter.NameFilter;
import org.tinygroup.vfs.FileObject;
import org.tinygroup.xmlparser.node.XmlNode;

/**
 * 全路径资源提供器实现类
 * 
 * @author luoguo
 * 
 */
public class FullContextFileFinder extends AbstractFileProcessor implements  AppConfig {
	private static final String FILE = "file";
	private static final String CONTENT_TYPE = "content-type";
	private static final String EXT_NAME = "ext-name";
	// application.xml full-context-file-finder节点名
	private static final String FULL_CONTEXT_FILE_FINDER = "full-context-file-finder";
	
	// 保存文件类型列表
	private Map<String, String> extFileContentTypeMap = new HashMap<String, String>();
	private XmlNode configuration;
	FullContextFileRepository fullContextFileRepository;
	private Map<String, FileObject> manualFileObjectMap = new HashMap<String, FileObject>();

	public FullContextFileRepository getFullContextFileRepository() {
		return fullContextFileRepository;
	}

	public void setFullContextFileRepository(
			FullContextFileRepository fullContextFileRepository) {
		this.fullContextFileRepository = fullContextFileRepository;
	}

	public boolean isMatch(FileObject fileObject) {
		if (extFileContentTypeMap.containsKey(fileObject.getExtName())) {
			return true;
		}
		return false;
	}

	private void process(FileObject fileObject) {
			fullContextFileRepository.addFileObject(fileObject.getPath(),fileObject);
	}

	public void process() {
	    fullContextFileRepository.setFileTypeMap(extFileContentTypeMap);
		for (FileObject fileObject : fileObjects) {
			process(fileObject);
		}
	}


	public String getNodeName() {
		return FULL_CONTEXT_FILE_FINDER;
	}

	public void setConfiguration(XmlNode xmlNode) {
		logger.logMessage(LogLevel.INFO, "配置信息：{0}", xmlNode.toString());
		this.configuration = xmlNode;
		NameFilter<XmlNode> nameFilter = new NameFilter<XmlNode>(configuration);
		List<XmlNode> fileNodes = nameFilter.findNodeList(FILE);
		for (XmlNode fileNode : fileNodes) {
			String extName = fileNode.getAttribute(EXT_NAME);
			String contentType = fileNode.getAttribute(CONTENT_TYPE);
			extFileContentTypeMap.put(extName, contentType);
		}
	}

	public XmlNode getConfiguration() {
		return configuration;
	}



	public void setFileResolver(FileResolver fileResolver) {
	}
}
